==> qrtool-0.12.1.tar.gz: qrtool-0.12.1/tests/completion.rs <==
// SPDX-FileCopyrightText: 2022 Shun Sakai
//
// SPDX-License-Identifier: Apache-2.0 OR MIT

mod utils;

use predicates::prelude::predicate;

#[test]
fn completion() {
    utils::command::command()
        .arg("completion")
        .arg("bash")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    utils::command::command()
        .arg("completion")
        .arg("elvish")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    utils::command::command()
        .arg("completion")
        .arg("fish")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    utils::command::command()
        .arg("completion")
        .arg("nushell")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    utils::command::command()
        .arg("completion")
        .arg("powershell")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    utils::command::command()
        .arg("completion")
        .arg("zsh")
        .assert()
        .success()
        .stdout(predicate::ne(""));
}

#[test]
fn infer_subcommand_name_for_completion_command() {
    utils::command::command()
        .arg("comp")
        .arg("-V")
        .assert()
        .success()
        .stdout(predicate::str::contains("qrtool-completion"));
    utils::command::command()
        .arg("c")
        .arg("-V")
        .assert()
        .success()
        .stdout(predicate::str::contains("qrtool-completion"));
}

#[test]
fn completion_with_invalid_shell() {
    utils::command::command()
        .arg("completion")
        .arg("a")
        .assert()
        .failure()
        .code(2)
        .stderr(predicate::str::contains("invalid value 'a' for '<SHELL>'"));
}

==> qrtool-0.13.0.tar.gz: qrtool-0.13.0/tests/completion.rs <==
// SPDX-FileCopyrightText: 2022 Shun Sakai
//
// SPDX-License-Identifier: Apache-2.0 OR MIT

mod utils;

use predicates::prelude::predicate;

use crate::utils::command;

#[test]
fn completion() {
    command::command()
        .arg("completion")
        .arg("bash")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    command::command()
        .arg("completion")
        .arg("elvish")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    command::command()
        .arg("completion")
        .arg("fish")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    command::command()
        .arg("completion")
        .arg("nushell")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    command::command()
        .arg("completion")
        .arg("powershell")
        .assert()
        .success()
        .stdout(predicate::ne(""));
    command::command()
        .arg("completion")
        .arg("zsh")
        .assert()
        .success()
        .stdout(predicate::ne(""));
}

#[test]
fn infer_subcommand_name_for_completion_command() {
    command::command()
        .arg("comp")
        .arg("-V")
        .assert()
        .success()
        .stdout(predicate::str::contains("qrtool-completion"));
    command::command()
        .arg("c")
        .arg("-V")
        .assert()
        .success()
        .stdout(predicate::str::contains("qrtool-completion"));
}

#[test]
fn completion_with_invalid_shell() {
    command::command()
        .arg("completion")
        .arg("a")
        .assert()
        .failure()
        .code(2)
        .stderr(predicate::str::contains("invalid value 'a' for '<SHELL>'"));
}
